yakumo.neutron.v2.quota.Manager

Package yakumo :: Package neutron :: Package v2 :: Module quota :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for quotas in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for quotas in Networking V2 API

Instance Methods | [hide private]
yakumo.base.Resource |
get(self, project) Aquire an existing resource object | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``project``'``,` `'``tenant_id``'``,` <yakumo.mapper.Resou`...``
| _hidden_methods = ``[``'``create``'``]``
| _id_attr = ``'``project``'``
| _json_resource_key = ``'``quota``'``
| _json_resources_key = ``'``quotas``'``
| _url_resource_path = ``'``/v2.0/quotas``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get(self, project) | source code
Aquire an existing resource object Parameters: `id` - ID Returns: yakumo.base.Resource Resource object Overrides: base.Manager.get (inherited documentation)

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('project',
        'tenant_id',
        <yakumo.mapper.Resource object at 0x7f1333c44c90>),
       ('subnet',
        'subnet',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('ikepolicy',
        'ikepolicy',
      ...